@@ -317,10 +317,9 @@ pub(crate) fn read_fibexes(files: Vec<PathBuf>) -> Result<FibexMetadata, Error>
                     description,
                     signal_types: signal_refs
                         .into_iter()
-                        .map(|type_ref| {
+                        .filter_map(|type_ref| {
                             type_info_for_signal_ref(type_ref, &signals_map, &codings_map)
                         })
-                        .flatten()
                         .collect(),
                 });
             }
@@ -481,6 +480,7 @@ const B_CODING_REF: &[u8] = b"CODING-REF";
 const B_BASE_DATA_TYPE: &[u8] = b"BASE-DATA-TYPE";
 const B_CODED_TYPE: &[u8] = b"CODED-TYPE";
 
+#[allow(dead_code)]
 #[derive(Debug)]
 pub(crate) enum Event {
     PduStart {
